@@ -1,8 +1,7 @@
 /* vim: set noet ts=4:
- * $Id: wmweather.c,v 1.91 2007/05/13 17:27:21 martin Exp $
  *
  * Copyright (c) 1999 Michael G. Henderson <mghenderson@lanl.gov>.
- * Copyright (c) 2002-2007 Martin A. Godisch <martin@godisch.de>.
+ * Copyright (c) 2002-2016 Martin A. Godisch <martin@godisch.de>.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -62,7 +61,7 @@ CURL
 static struct memory
 	header = {NULL, 0};
 char
-	url[]       = "http://weather.noaa.gov/pub/data/observations/metar/decoded/\0\0\0\0.TXT",
+	url[]       = "http://tgftp.nws.noaa.gov/data/observations/metar/decoded/\0\0\0\0.TXT",
 	xtitle[]    = "weather report for \0\0\0\0\0",
 	*station    = NULL,
 	*report     = NULL,
@@ -251,7 +250,7 @@ static void do_conf(const char *rcfile)
 		return;
 	}
 	for (line = 1;; line++) {
-		fgets(buffer, sizeof(buffer), F);
+		p = fgets(buffer, sizeof(buffer), F);
 		if (feof(F))
 			break;
 		if ((p = index(buffer, '\n')) != NULL)
@@ -520,12 +519,12 @@ static void do_opts(int argc, char *argv[])
 			printf("  --wgc=<color>         gusty-wind (variable direction) color,\n");
 			printf("  --tc=<color>          station ID and time color.\n");
 			printf("System-wide configuration file is %s.\n", SYSCONFPATH);
-			printf("For ICAO location indicators visit http://www.nws.noaa.gov/tg/siteloc.shtml.\n");
+			printf("For ICAO location indicators visit http://www.nws.noaa.gov/tg/siteloc.php.\n");
 			exit(0);
 		case 'v':
 			printf("%s\n", PACKAGE_STRING);
 			printf("copyright (c) 1999 Michael G. Henderson <mghenderson@lanl.gov>\n");
-			printf("copyright (c) 2002-2007 Martin A. Godisch <martin@godisch.de>\n");
+			printf("copyright (c) 2002-2016 Martin A. Godisch <martin@godisch.de>\n");
 			exit(0);
 		case 0:
 		case 1:
@@ -740,7 +739,7 @@ static void update(int force_read)
 		windspeed        = 0;
 		pressure         = 0;
 		for (line = 1;; line++) {
-			fgets(buffer, MAX_STRING, F);
+			i = fgets(buffer, MAX_STRING, F);
 			if (feof(F))
 				break;
 
